@@ -8,7 +8,7 @@ test_that("lagos_load fails well", {
 
   expect_error(lagosne_load("gibberish"),
     paste0("Dataset not found at: ",
-    paste0(lagos_path(), "data_", "gibberish", ".rds"),
+    paste0(lagos_path(), "data_", "gibberish", ".qs"),
     "\n Try running the `lagosne_get` command."),
     fixed = TRUE)
 })
